@@ -18,6 +18,7 @@ from .config import DOCUMENT_SIZE_THRESHOLD_BYTES
 class BaseSchema(Schema):
     class Meta:
         ordered = True
+        unknown = EXCLUDE
 
 
 class Base:
@@ -47,9 +48,6 @@ class Base:
 
 
 class DocumentSchema(BaseSchema):
-    class Meta:
-        unknown = EXCLUDE
-
     filename = fields.String(validate=validate.Length(max=256), allow_none=True)
     document = fields.String(required=True)
 
@@ -218,8 +216,8 @@ class PolicyBreak(Base):
         self,
         break_type: str,
         policy: str,
-        validity: Optional[str],
         matches: List[Match],
+        validity: Optional[str] = None,
         **kwargs: Any,
     ) -> None:
         super().__init__()
@@ -484,9 +482,9 @@ class HealthCheckResponse(Base):
     def __init__(
         self,
         detail: str,
-        status_code: Optional[int],
-        app_version: Optional[str],
-        secrets_engine_version: Optional[str],
+        status_code: int,
+        app_version: Optional[str] = None,
+        secrets_engine_version: Optional[str] = None,
         **kwargs: Any,
     ):
         super().__init__()
